@@ -125,23 +125,6 @@ def host_list_extract():
             multi_proc_batch_number=multi_proc_batch_number)
 
 
-def setup_vars_required_for_direct_execution_of_main():
-    global host_list_vm_processed_after
-    global xml_file
-    (min_date, max_date) = etld_lib_sqlite_tables.get_q_table_min_max_dates(
-        etld_lib_config.host_list_sqlite_file,"LAST_VULN_SCAN_DATETIME", "Q_Host_List")
-    etld_lib_functions.logger.info(f"Found Q_Host_List Min Date: {min_date} Max Date: {max_date}")
-    # TODO start from LAST_VULN_SCAN_DATETIME max with seconds set to zero.
-    if max_date == 'Not Found':
-        pass
-    else:
-        pass
-#        host_list_vm_processed_after = re.sub(" .*$", "T00:00:00Z", max_date)  # TODO focus on seconds
-#        etld_lib_functions.logger.info(f"Found host list max date of: {max_date}")
-#        etld_lib_config.host_list_vm_processed_after = host_list_vm_processed_after
-#        etld_lib_functions.logger.info(f"     using host_list_vm_processed_after={host_list_vm_processed_after}")
-
-
 def start_msg_host_list_extract():
     etld_lib_functions.logger.info(f"start ")
 
